TIMELINES = "timelines"
SCENES = "scenes"
BOTH = "both"

sceneGroups = {
    ["A"] = {1,2,3,4},
    ["B"] = {5,6,7,8},
    ["C"] = {9,10,11,12},
    ["D"] = {13,14,15,16},
    ["E"] = {17,18,19,20}
}

timelineGroups = {
    ["A"] = {1,2,3,4},
    ["B"] = {5,6,7,8},
    ["C"] = {9,10,11,12},
    ["D"] = {13,14,15,16},
    ["E"] = {17,18,19,20}
}

function custom_release_all(object, group, except, fade)

    fadeTime = fade or 0                                        -- Default fade time to 0s
    object = object or "both"                                   -- Default object to both
    group = group or "all"                                      -- Default group to empty
    except = except or false                                    -- Default except to false

    if object == "timelines" or object == "both" then           -- Timelines or both chosen
        if group == "all" then                                  -- Release All Timelines
            for k,v in pairs(timelineGroups) do                 -- Loop through timelineGroups table
                for i = 1, #v do                                -- Go through timelines in group
                    get_timeline(v[i]):release(fadeTime)        -- Release timeline
                end
            end
        else
            for k,v in pairs(timelineGroups) do                 -- Loop through timelineGroups table
                if except then
                    if k ~= group then                          -- Ignore excepted group group
                        for i = 1, #v do                        -- Go through timelines in group
                            get_timeline(v[i]):release(fadeTime)-- Release timeline
                        end
                    end
                else
                    if k == group then                          -- Only release specified group
                        for i = 1, #v do                        -- Go through timelines in group
                            get_timeline(v[i]):release(fadeTime)-- Release timeline
                        end
                    end
                end
            end
        end
    end

    if object == "scenes" or object == "both" then           -- Scenes or both chosen
        if group == "all" then                               -- Release All Timelines
            for k,v in pairs(sceneGroups) do                 -- Loop through sceneGroups table
                for i = 1, #v do                             -- Go through scenes in group
                    get_scene(v[i]):release(fadeTime)        -- Release scene
                end
            end
        else
            for k,v in pairs(sceneGroups) do                 -- Loop through sceneGroups table
                if except then
                    if k ~= group then                       -- Ignore excepted group group
                        for i = 1, #v do                     -- Go through scenes in group
                            get_scene(v[i]):release(fadeTime)-- Release scene
                        end
                    end
                else
                    if k == group then                       -- Only release specified group
                        for i = 1, #v do                     -- Go through scenes in group
                            get_scene(v[i]):release(fadeTime)-- Release scene
                        end
                    end
                end
            end
        end
    end
end

--[[
Custom Release All Except fucntionality

Defining groups:
    The top section is used to define the Timeline and Scene groups
    sceneGroups = {
        [group_name] = {objects},
        [group_name] = {objects}
    }

    timelineGroups = {
        [group_name] = {objects},
        [group_name] = {objects}
    }

    group_name = a string to name the group e.g. "A"
    objects    = a comma separated list of the timelines or scenes in the group

    Multiple groups can be defined here

Usage:
    custom_release_all_except(object, group, except, fade)

    object     = "timelines", "scenes", "both" or TIMELINES, SCENES, BOTH
    group      = the group name e.g. "A"
    except     = whether this should be except group or only group (true or false)
    fade       = fade time in seconds

    example:
        custom_release_all_except(TIMELINES, "A", 2)
        will release all timelines except group A in 2 seconds

--]]